@@ -2,7 +2,7 @@
  * smb.c: SMB input module
  *****************************************************************************
  * Copyright (C) 2001-2009 VLC authors and VideoLAN
- * $Id: 1e681aa276f765f33080e9ec8d893993a17d17f9 $
+ * $Id: b766b9bd447c9080fcbc8df2d421c0ce8dcc420f $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *
@@ -91,6 +91,7 @@ static int Control( access_t *, int, va_list );
 struct access_sys_t
 {
     int i_smb;
+    uint64_t size;
 };
 
 #ifdef _WIN32
@@ -218,8 +219,8 @@ static int Open( vlc_object_t *p_this )
 #endif
     if( (i_smb = smbc_open( psz_uri, O_RDONLY, 0 )) < 0 )
     {
-        msg_Err( p_access, "open failed for '%s' (%m)",
-                 p_access->psz_location );
+        msg_Err( p_access, "open failed for '%s' (%s)",
+                 p_access->psz_location, vlc_strerror_c(errno) );
         free( psz_uri );
         return VLC_EGENERIC;
     }
@@ -231,10 +232,10 @@ static int Open( vlc_object_t *p_this )
     if( i_ret )
     {
         errno = i_ret;
-        msg_Err( p_access, "stat failed (%m)" );
+        msg_Err( p_access, "stat failed (%s)", vlc_strerror_c(errno) );
     }
     else
-        p_access->info.i_size = filestat.st_size;
+        p_sys->size = filestat.st_size;
 
     free( psz_uri );
 
@@ -271,7 +272,7 @@ static int Seek( access_t *p_access, uint64_t i_pos )
     i_ret = smbc_lseek( p_sys->i_smb, i_pos, SEEK_SET );
     if( i_ret == -1 )
     {
-        msg_Err( p_access, "seek failed (%m)" );
+        msg_Err( p_access, "seek failed (%s)", vlc_strerror_c(errno) );
         return VLC_EGENERIC;
     }
 
@@ -294,7 +295,8 @@ static ssize_t Read( access_t *p_access, uint8_t *p_buffer, size_t i_len )
     i_read = smbc_read( p_sys->i_smb, p_buffer, i_len );
     if( i_read < 0 )
     {
-        msg_Err( p_access, "read failed (%m)" );
+        msg_Err( p_access, "read failed (%s)", vlc_strerror_c(errno) );
+        p_access->info.b_eof = true;
         return -1;
     }
 
@@ -318,6 +320,10 @@ static int Control( access_t *p_access, int i_query, va_list args )
         *va_arg( args, bool* ) = true;
         break;
 
+    case ACCESS_GET_SIZE:
+        *va_arg( args, uint64_t * ) = p_access->p_sys->size;
+        break;
+
     case ACCESS_GET_PTS_DELAY:
         *va_arg( args, int64_t * ) = INT64_C(1000)
             * var_InheritInteger( p_access, "network-caching" );
@@ -327,17 +333,8 @@ static int Control( access_t *p_access, int i_query, va_list args )
         /* Nothing to do */
         break;
 
-    case ACCESS_GET_TITLE_INFO:
-    case ACCESS_SET_TITLE:
-    case ACCESS_SET_SEEKPOINT:
-    case ACCESS_SET_PRIVATE_ID_STATE:
-    case ACCESS_GET_CONTENT_TYPE:
-        return VLC_EGENERIC;
-
     default:
-        msg_Warn( p_access, "unimplemented query in control" );
         return VLC_EGENERIC;
-
     }
 
     return VLC_SUCCESS;
