@@ -3,7 +3,7 @@
  *               -> gives the feeling of a real room with a simple headphone
  *****************************************************************************
  * Copyright (C) 2002-2006 the VideoLAN team
- * $Id: 92c1a3b24b8a9702e54deb2f25d3b94101794002 $
+ * $Id: 43c603273082ea1771648d676f3595246c07ef71 $
  *
  * Authors: Boris Dorès <babal@via.ecp.fr>
  *
@@ -105,7 +105,7 @@ struct atomic_operation_t
 struct filter_sys_t
 {
     size_t i_overflow_buffer_size;/* in bytes */
-    uint8_t * p_overflow_buffer;
+    float * p_overflow_buffer;
     unsigned int i_nb_atomic_operations;
     struct atomic_operation_t * p_atomic_operations;
 };
@@ -315,7 +315,7 @@ static int Init( vlc_object_t *p_this, struct filter_sys_t * p_data
                 = p_data->p_atomic_operations[i].i_delay * 2 * sizeof (float);
         }
     }
-    p_data->p_overflow_buffer = malloc( p_data->i_overflow_buffer_size );
+    p_data->p_overflow_buffer = (float *)malloc( p_data->i_overflow_buffer_size );
     if( p_data->p_overflow_buffer == NULL )
     {
         free( p_data->p_atomic_operations );
@@ -337,8 +337,9 @@ static void DoWork( filter_t * p_filter,
     int i_output_nb = aout_FormatNbChannels( &p_filter->fmt_out.audio );
 
     float * p_in = (float*) p_in_buf->p_buffer;
-    uint8_t * p_out;
+    float * p_out;
     uint8_t * p_overflow;
+    uint8_t * p_end_overflow;
     uint8_t * p_slide;
 
     size_t i_overflow_size;     /* in bytes */
@@ -351,39 +352,37 @@ static void DoWork( filter_t * p_filter,
     unsigned int i_delay;
     double d_amplitude_factor;
 
-    /* out buffer characterisitcs */
-    p_out_buf->i_nb_samples = p_in_buf->i_nb_samples;
-    p_out_buf->i_buffer = p_in_buf->i_buffer * i_output_nb / i_input_nb;
-    p_out = p_out_buf->p_buffer;
+    p_out = (float *)p_out_buf->p_buffer;
     i_out_size = p_out_buf->i_buffer;
 
     /* Slide the overflow buffer */
-    p_overflow = p_sys->p_overflow_buffer;
+    p_overflow = (uint8_t *) p_sys->p_overflow_buffer;
     i_overflow_size = p_sys->i_overflow_buffer_size;
+    p_end_overflow = p_overflow + i_overflow_size;
 
     memset( p_out, 0, i_out_size );
-    if ( i_out_size > i_overflow_size )
-        memcpy( p_out, p_overflow, i_overflow_size );
-    else
-        memcpy( p_out, p_overflow, i_out_size );
+    memcpy( p_out, p_overflow, __MIN( i_out_size, i_overflow_size ) );
 
-    p_slide = p_sys->p_overflow_buffer;
-    while( p_slide < p_overflow + i_overflow_size )
+    p_slide = (uint8_t *) p_sys->p_overflow_buffer;
+    while( p_slide < p_end_overflow )
     {
-        if( p_slide + i_out_size < p_overflow + i_overflow_size )
+        size_t i_bytes_copied;
+
+        if( p_slide + i_out_size < p_end_overflow )
         {
             memset( p_slide, 0, i_out_size );
-            if( p_slide + 2 * i_out_size < p_overflow + i_overflow_size )
-                memcpy( p_slide, p_slide + i_out_size, i_out_size );
+            if( p_slide + 2 * i_out_size < p_end_overflow )
+                i_bytes_copied = i_out_size;
             else
-                memcpy( p_slide, p_slide + i_out_size,
-                        p_overflow + i_overflow_size - ( p_slide + i_out_size ) );
+                i_bytes_copied = p_end_overflow - ( p_slide + i_out_size );
+            memcpy( p_slide, p_slide + i_out_size, i_bytes_copied );
         }
         else
         {
-            memset( p_slide, 0, p_overflow + i_overflow_size - p_slide );
+            i_bytes_copied = p_end_overflow - p_slide;
+            memset( p_slide, 0, i_bytes_copied );
         }
-        p_slide += i_out_size;
+        p_slide += i_bytes_copied;
     }
 
     /* apply the atomic operations */
@@ -506,9 +505,9 @@ static block_t *Convert( filter_t *p_filter, block_t *p_block )
         return NULL;
     }
 
-    size_t i_out_size = p_block->i_nb_samples *
-      p_filter->fmt_out.audio.i_bitspersample/8 *
-        aout_FormatNbChannels( &(p_filter->fmt_out.audio) );
+    size_t i_out_size = p_block->i_buffer *
+        aout_FormatNbChannels( &(p_filter->fmt_out.audio) ) /
+        aout_FormatNbChannels( &(p_filter->fmt_in.audio) );
 
     block_t *p_out = block_Alloc( i_out_size );
     if( !p_out )
