@@ -2,7 +2,7 @@
  * qtl.c: QuickTime Media Link Importer
  *****************************************************************************
  * Copyright (C) 2006 VLC authors and VideoLAN
- * $Id: f3514d28beff7340771da6a07fff50e51e487880 $
+ * $Id: 958b29e0afd783c8703515c0843ac306dbc98ea9 $
  *
  * Authors: Antoine Cellerier <dionoea -@t- videolan -Dot- org>
  *
@@ -57,6 +57,7 @@ volume - 0 (mute) - 100 (max)
 
 #include "playlist.h"
 #include <vlc_xml.h>
+#include <vlc_strings.h>
 
 typedef enum { FULLSCREEN_NORMAL,
                FULLSCREEN_DOUBLE,
@@ -243,6 +244,7 @@ static int Demux( demux_t *p_demux )
         vlc_gc_decref( p_input );
         if( psz_qtnext )
         {
+            resolve_xml_special_chars( psz_qtnext );
             p_input = input_item_New( psz_qtnext, NULL );
             input_item_node_AppendItem( p_subitems, p_input );
             vlc_gc_decref( p_input );
