@@ -1,27 +1,27 @@
 /*****************************************************************************
  * audio.c: transcoding stream output module (audio)
  *****************************************************************************
- * Copyright (C) 2003-2009 the VideoLAN team
- * $Id: 5d313dbc44264f97aebbd82f0d6f4d0cd3314fc5 $
+ * Copyright (C) 2003-2009 VLC authors and VideoLAN
+ * $Id: 60124202114cffcafc6cf60f0a6f025a3a6cce4a $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Gildas Bazin <gbazin@videolan.org>
  *          Jean-Paul Saman <jpsaman #_at_# m2x dot nl>
  *          Antoine Cellerier <dionoea at videolan dot org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 /*****************************************************************************
@@ -35,44 +35,34 @@
 #include <vlc_meta.h>
 #include <vlc_modules.h>
 
-static const int pi_channels_maps[6] =
+static const int pi_channels_maps[9] =
 {
     0,
-    AOUT_CHAN_CENTER,   AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT,
-    AOUT_CHAN_CENTER | AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT,
+    AOUT_CHAN_CENTER,
+    AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT,
+    AOUT_CHAN_LFE  | AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT,
     AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT | AOUT_CHAN_REARLEFT
      | AOUT_CHAN_REARRIGHT,
     AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT | AOUT_CHAN_CENTER
-     | AOUT_CHAN_REARLEFT | AOUT_CHAN_REARRIGHT
+     | AOUT_CHAN_REARLEFT | AOUT_CHAN_REARRIGHT,
+    AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT | AOUT_CHAN_CENTER
+     | AOUT_CHAN_REARLEFT | AOUT_CHAN_REARRIGHT | AOUT_CHAN_LFE,
+    AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT | AOUT_CHAN_CENTER
+     | AOUT_CHAN_REARCENTER | AOUT_CHAN_MIDDLELEFT
+     | AOUT_CHAN_MIDDLERIGHT | AOUT_CHAN_LFE,
+    AOUT_CHAN_LEFT | AOUT_CHAN_RIGHT | AOUT_CHAN_CENTER | AOUT_CHAN_REARLEFT
+     | AOUT_CHAN_REARRIGHT | AOUT_CHAN_MIDDLELEFT | AOUT_CHAN_MIDDLERIGHT
+     | AOUT_CHAN_LFE,
 };
 
-static block_t *audio_new_buffer( decoder_t *p_dec, int i_samples )
+static int audio_update_format( decoder_t *p_dec )
 {
-    block_t *p_block;
-    int i_size;
-
-    if( p_dec->fmt_out.audio.i_bitspersample )
-    {
-        i_size = i_samples * p_dec->fmt_out.audio.i_bitspersample / 8 *
-            p_dec->fmt_out.audio.i_channels;
-    }
-    else if( p_dec->fmt_out.audio.i_bytes_per_frame &&
-             p_dec->fmt_out.audio.i_frame_length )
-    {
-        i_size = i_samples * p_dec->fmt_out.audio.i_bytes_per_frame /
-            p_dec->fmt_out.audio.i_frame_length;
-    }
-    else
-    {
-        i_size = i_samples * 4 * p_dec->fmt_out.audio.i_channels;
-    }
-
-    p_block = block_Alloc( i_size );
-    p_block->i_nb_samples = i_samples;
-    return p_block;
+    aout_FormatPrepare( &p_dec->fmt_out.audio );
+    return 0;
 }
 
-static int transcode_audio_initialize_filters( sout_stream_t *p_stream, sout_stream_id_t *id, sout_stream_sys_t *p_sys, audio_sample_format_t *fmt_last )
+static int transcode_audio_initialize_filters( sout_stream_t *p_stream, sout_stream_id_sys_t *id,
+                                               sout_stream_sys_t *p_sys, audio_sample_format_t *fmt_last )
 {
     /* Load user specified audio filters */
     /* XXX: These variable names come kinda out of nowhere... */
@@ -93,13 +83,58 @@ static int transcode_audio_initialize_filters( sout_stream_t *p_stream, sout_str
         id->p_decoder->p_module = NULL;
         return VLC_EGENERIC;
     }
-    p_sys->fmt_audio.i_rate = fmt_last->i_rate;
-    p_sys->fmt_audio.i_physical_channels = fmt_last->i_physical_channels;
+    id->fmt_audio.i_rate = fmt_last->i_rate;
+    id->fmt_audio.i_physical_channels = fmt_last->i_physical_channels;
+    return VLC_SUCCESS;
+}
+
+static int transcode_audio_initialize_encoder( sout_stream_id_sys_t *id, sout_stream_t *p_stream )
+{
+    sout_stream_sys_t *p_sys = p_stream->p_sys;
+    /* Initialization of encoder format structures */
+    es_format_Init( &id->p_encoder->fmt_in, id->p_decoder->fmt_in.i_cat,
+                    id->p_decoder->fmt_out.i_codec );
+    id->p_encoder->fmt_in.audio.i_format = id->p_decoder->fmt_out.i_codec;
+    id->p_encoder->fmt_in.audio.i_rate = id->p_encoder->fmt_out.audio.i_rate;
+    id->p_encoder->fmt_in.audio.i_physical_channels =
+        id->p_encoder->fmt_out.audio.i_physical_channels;
+    aout_FormatPrepare( &id->p_encoder->fmt_in.audio );
+
+    id->p_encoder->p_cfg = p_stream->p_sys->p_audio_cfg;
+    id->p_encoder->p_module =
+        module_need( id->p_encoder, "encoder", p_sys->psz_aenc, true );
+    /* p_sys->i_acodec = 0 if there isn't acodec defined */
+    if( !id->p_encoder->p_module && p_sys->i_acodec )
+    {
+        msg_Err( p_stream, "cannot find audio encoder (module:%s fourcc:%4.4s). "
+                           "Take a look few lines earlier to see possible reason.",
+                 p_sys->psz_aenc ? p_sys->psz_aenc : "any",
+                 (char *)&p_sys->i_acodec );
+        module_unneed( id->p_decoder, id->p_decoder->p_module );
+        id->p_decoder->p_module = NULL;
+        return VLC_EGENERIC;
+    }
+
+    id->p_encoder->fmt_out.i_codec =
+        vlc_fourcc_GetCodec( AUDIO_ES, id->p_encoder->fmt_out.i_codec );
+
+    /* Fix input format */
+    id->p_encoder->fmt_in.audio.i_format = id->p_encoder->fmt_in.i_codec;
+    if( !id->p_encoder->fmt_in.audio.i_physical_channels
+     || !id->p_encoder->fmt_in.audio.i_original_channels )
+    {
+        if( id->p_encoder->fmt_in.audio.i_channels < (sizeof(pi_channels_maps) / sizeof(*pi_channels_maps)) )
+            id->p_encoder->fmt_in.audio.i_physical_channels =
+            id->p_encoder->fmt_in.audio.i_original_channels =
+                      pi_channels_maps[id->p_encoder->fmt_in.audio.i_channels];
+    }
+    aout_FormatPrepare( &id->p_encoder->fmt_in.audio );
+
     return VLC_SUCCESS;
 }
 
 int transcode_audio_new( sout_stream_t *p_stream,
-                                sout_stream_id_t *id )
+                                sout_stream_id_sys_t *id )
 {
     sout_stream_sys_t *p_sys = p_stream->p_sys;
     audio_sample_format_t fmt_last;
@@ -113,9 +148,8 @@ int transcode_audio_new( sout_stream_t *p_stream,
     id->p_decoder->fmt_out.i_extra = 0;
     id->p_decoder->fmt_out.p_extra = 0;
     id->p_decoder->pf_decode_audio = NULL;
-    id->p_decoder->pf_aout_buffer_new = audio_new_buffer;
+    id->p_decoder->pf_aout_format_update = audio_update_format;
     /* id->p_decoder->p_cfg = p_sys->p_audio_cfg; */
-
     id->p_decoder->p_module =
         module_need( id->p_decoder, "decoder", "$codec", false );
     if( !id->p_decoder->p_module )
@@ -136,51 +170,17 @@ int transcode_audio_new( sout_stream_t *p_stream,
     /*
      * Open encoder
      */
-
-    /* Initialization of encoder format structures */
-    es_format_Init( &id->p_encoder->fmt_in, id->p_decoder->fmt_in.i_cat,
-                    id->p_decoder->fmt_out.i_codec );
-    id->p_encoder->fmt_in.audio.i_format = id->p_decoder->fmt_out.i_codec;
-    id->p_encoder->fmt_in.audio.i_rate = id->p_encoder->fmt_out.audio.i_rate;
-    id->p_encoder->fmt_in.audio.i_physical_channels =
-        id->p_encoder->fmt_out.audio.i_physical_channels;
-    aout_FormatPrepare( &id->p_encoder->fmt_in.audio );
-
-    id->p_encoder->p_cfg = p_stream->p_sys->p_audio_cfg;
-    id->p_encoder->p_module =
-        module_need( id->p_encoder, "encoder", p_sys->psz_aenc, true );
-    if( !id->p_encoder->p_module )
-    {
-        msg_Err( p_stream, "cannot find audio encoder (module:%s fourcc:%4.4s). Take a look few lines earlier to see possible reason.",
-                 p_sys->psz_aenc ? p_sys->psz_aenc : "any",
-                 (char *)&p_sys->i_acodec );
-        module_unneed( id->p_decoder, id->p_decoder->p_module );
-        id->p_decoder->p_module = NULL;
+    if( transcode_audio_initialize_encoder( id, p_stream ) == VLC_EGENERIC )
         return VLC_EGENERIC;
-    }
 
-    id->p_encoder->fmt_out.i_codec =
-        vlc_fourcc_GetCodec( AUDIO_ES, id->p_encoder->fmt_out.i_codec );
-
-    /* Fix input format */
-    id->p_encoder->fmt_in.audio.i_format = id->p_encoder->fmt_in.i_codec;
-    if( !id->p_encoder->fmt_in.audio.i_physical_channels
-     || !id->p_encoder->fmt_in.audio.i_original_channels )
-    {
-        if( id->p_encoder->fmt_in.audio.i_channels < 6 )
-            id->p_encoder->fmt_in.audio.i_physical_channels =
-            id->p_encoder->fmt_in.audio.i_original_channels =
-                      pi_channels_maps[id->p_encoder->fmt_in.audio.i_channels];
-    }
-    aout_FormatPrepare( &id->p_encoder->fmt_in.audio );
-
-    if( unlikely( transcode_audio_initialize_filters( p_stream, id, p_sys, &fmt_last ) != VLC_SUCCESS ) )
+    if( unlikely( transcode_audio_initialize_filters( p_stream, id, p_sys,
+                                                      &fmt_last ) != VLC_SUCCESS ) )
         return VLC_EGENERIC;
 
     return VLC_SUCCESS;
 }
 
-void transcode_audio_close( sout_stream_id_t *id )
+void transcode_audio_close( sout_stream_id_sys_t *id )
 {
     /* Close decoder */
     if( id->p_decoder->p_module )
@@ -202,7 +202,7 @@ void transcode_audio_close( sout_stream_id_t *id )
 }
 
 int transcode_audio_process( sout_stream_t *p_stream,
-                                    sout_stream_id_t *id,
+                                    sout_stream_id_sys_t *id,
                                     block_t *in, block_t **out )
 {
     sout_stream_sys_t *p_sys = p_stream->p_sys;
@@ -222,9 +222,41 @@ int transcode_audio_process( sout_stream_t *p_stream,
     while( (p_audio_buf = id->p_decoder->pf_decode_audio( id->p_decoder,
                                                           &in )) )
     {
+        if( unlikely( !id->p_encoder->p_module ) )
+        {
+            /* Complete destination format */
+            id->p_encoder->fmt_out.i_codec = p_sys->i_acodec;
+            id->p_encoder->fmt_out.audio.i_rate = p_sys->i_sample_rate > 0 ?
+                p_sys->i_sample_rate : id->p_decoder->fmt_out.audio.i_rate;
+            id->p_encoder->fmt_out.i_bitrate = p_sys->i_abitrate;
+            id->p_encoder->fmt_out.audio.i_bitspersample =
+                id->p_decoder->fmt_out.audio.i_bitspersample;
+            id->p_encoder->fmt_out.audio.i_channels = p_sys->i_channels > 0 ?
+                p_sys->i_channels : id->p_decoder->fmt_out.audio.i_channels;
+
+            id->p_encoder->fmt_in.audio.i_original_channels =
+            id->p_encoder->fmt_out.audio.i_original_channels =
+                id->p_decoder->fmt_out.audio.i_physical_channels;
+
+            id->p_encoder->fmt_in.audio.i_physical_channels =
+            id->p_encoder->fmt_out.audio.i_physical_channels =
+                pi_channels_maps[id->p_encoder->fmt_out.audio.i_channels];
+
+            if( transcode_audio_initialize_encoder( id, p_stream ) )
+            {
+                msg_Err( p_stream, "cannot create audio chain" );
+                return VLC_EGENERIC;
+            }
+            if( unlikely( transcode_audio_initialize_filters( p_stream, id, p_sys,
+                          &id->p_decoder->fmt_out.audio ) != VLC_SUCCESS ) )
+                return VLC_EGENERIC;
+            date_Init( &id->next_input_pts, id->p_decoder->fmt_out.audio.i_rate, 1 );
+            date_Set( &id->next_input_pts, p_audio_buf->i_pts );
+        }
+
         /* Check if audio format has changed, and filters need reinit */
-        if( unlikely( ( id->p_decoder->fmt_out.audio.i_rate != p_sys->fmt_audio.i_rate ) ||
-                      ( id->p_decoder->fmt_out.audio.i_physical_channels != p_sys->fmt_audio.i_physical_channels ) ) )
+        if( unlikely( ( id->p_decoder->fmt_out.audio.i_rate != id->fmt_audio.i_rate ) ||
+                      ( id->p_decoder->fmt_out.audio.i_physical_channels != id->fmt_audio.i_physical_channels ) ) )
         {
             msg_Info( p_stream, "Audio changed, trying to reinitialize filters" );
             if( id->p_af_chain != NULL )
@@ -234,14 +266,18 @@ int transcode_audio_process( sout_stream_t *p_stream,
             id->p_decoder->fmt_out.audio.i_format = id->p_decoder->fmt_out.i_codec;
             aout_FormatPrepare( &id->p_decoder->fmt_out.audio );
 
-            if( transcode_audio_initialize_filters( p_stream, id, p_sys, &id->p_decoder->fmt_out.audio ) != VLC_SUCCESS )
+            if( transcode_audio_initialize_filters( p_stream, id, p_sys,
+                          &id->p_decoder->fmt_out.audio ) != VLC_SUCCESS )
                 return VLC_EGENERIC;
 
+            /* Set next_input_pts to run with new samplerate */
+            date_Init( &id->next_input_pts, id->fmt_audio.i_rate, 1 );
+            date_Set( &id->next_input_pts, p_audio_buf->i_pts );
         }
 
         if( p_sys->b_master_sync )
         {
-            mtime_t i_pts = date_Get( &id->interpolated_pts ) + 1;
+            mtime_t i_pts = date_Get( &id->next_input_pts );
             mtime_t i_drift = 0;
 
             if( likely( p_audio_buf->i_pts != VLC_TS_INVALID ) )
@@ -251,36 +287,19 @@ int transcode_audio_process( sout_stream_t *p_stream,
                  || i_drift < -MASTER_SYNC_MAX_DRIFT) )
             {
                 msg_Dbg( p_stream,
-                    "drift is too high (%"PRId64"), resetting master sync",
+                    "audio drift is too high (%"PRId64"), resetting master sync",
                     i_drift );
-                date_Set( &id->interpolated_pts, p_audio_buf->i_pts );
-                i_pts = p_audio_buf->i_pts + 1;
+                date_Set( &id->next_input_pts, p_audio_buf->i_pts );
+                i_pts = date_Get( &id->next_input_pts );
+                if( likely(p_audio_buf->i_pts != VLC_TS_INVALID ) )
+                    i_drift = p_audio_buf->i_pts - i_pts;
             }
-            if( likely(p_audio_buf->i_pts != VLC_TS_INVALID ) )
-                p_sys->i_master_drift = p_audio_buf->i_pts - i_pts;
-            date_Increment( &id->interpolated_pts, p_audio_buf->i_nb_samples );
-            p_audio_buf->i_pts = i_pts;
+            p_sys->i_master_drift = i_drift;
+            date_Increment( &id->next_input_pts, p_audio_buf->i_nb_samples );
         }
 
         p_audio_buf->i_dts = p_audio_buf->i_pts;
 
-        /* Check if audio format has changed, and filters need reinit */
-        if( unlikely( ( id->p_decoder->fmt_out.audio.i_rate != p_sys->fmt_audio.i_rate ) ||
-                      ( id->p_decoder->fmt_out.audio.i_physical_channels != p_sys->fmt_audio.i_physical_channels ) ) )
-        {
-            msg_Info( p_stream, "Audio changed, trying to reinitialize filters" );
-            if( id->p_af_chain != NULL )
-                aout_FiltersDelete( (vlc_object_t *)NULL, id->p_af_chain );
-
-            /* decoders don't set audio.i_format, but audio filters use it */
-            id->p_decoder->fmt_out.audio.i_format = id->p_decoder->fmt_out.i_codec;
-            aout_FormatPrepare( &id->p_decoder->fmt_out.audio );
-
-            if( transcode_audio_initialize_filters( p_stream, id, p_sys, &id->p_decoder->fmt_out.audio ) != VLC_SUCCESS )
-                return VLC_EGENERIC;
-
-        }
-
         /* Run filter chain */
         p_audio_buf = aout_FiltersPlay( id->p_af_chain, p_audio_buf,
                                         INPUT_RATE_DEFAULT );
@@ -299,7 +318,7 @@ int transcode_audio_process( sout_stream_t *p_stream,
 }
 
 bool transcode_audio_add( sout_stream_t *p_stream, es_format_t *p_fmt, 
-            sout_stream_id_t *id )
+            sout_stream_id_sys_t *id )
 {
     sout_stream_sys_t *p_sys = p_stream->p_sys;
 
@@ -316,17 +335,17 @@ bool transcode_audio_add( sout_stream_t *p_stream, es_format_t *p_fmt,
         p_fmt->audio.i_bitspersample;
     id->p_encoder->fmt_out.audio.i_channels = p_sys->i_channels > 0 ?
         p_sys->i_channels : p_fmt->audio.i_channels;
-    /* Sanity check for audio channels */
-    id->p_encoder->fmt_out.audio.i_channels =
-        __MIN( id->p_encoder->fmt_out.audio.i_channels,
-               id->p_decoder->fmt_in.audio.i_channels );
+
+    id->p_encoder->fmt_in.audio.i_original_channels =
     id->p_encoder->fmt_out.audio.i_original_channels =
-        id->p_decoder->fmt_in.audio.i_physical_channels;
+        id->p_decoder->fmt_out.audio.i_physical_channels;
+
+    id->p_encoder->fmt_in.audio.i_physical_channels =
     id->p_encoder->fmt_out.audio.i_physical_channels =
             pi_channels_maps[id->p_encoder->fmt_out.audio.i_channels];
 
     /* Build decoder -> filter -> encoder chain */
-    if( transcode_audio_new( p_stream, id ) )
+    if( transcode_audio_new( p_stream, id ) == VLC_EGENERIC )
     {
         msg_Err( p_stream, "cannot create audio chain" );
         return false;
@@ -342,7 +361,21 @@ bool transcode_audio_add( sout_stream_t *p_stream, es_format_t *p_fmt,
         return false;
     }
 
-    date_Init( &id->interpolated_pts, p_fmt->audio.i_rate, 1 );
-
+    /* Reinit encoder again later on, when all information from decoders
+     * is available. */
+    if( id->p_encoder->p_module )
+    {
+        module_unneed( id->p_encoder, id->p_encoder->p_module );
+        id->p_encoder->p_module = NULL;
+        if( id->p_encoder->fmt_out.p_extra )
+        {
+            free( id->p_encoder->fmt_out.p_extra );
+            id->p_encoder->fmt_out.p_extra = NULL;
+            id->p_encoder->fmt_out.i_extra = 0;
+        }
+        if( id->p_af_chain != NULL )
+            aout_FiltersDelete( (vlc_object_t *)NULL, id->p_af_chain );
+        id->p_af_chain = NULL;
+    }
     return true;
 }
